"use strict";

/* exported logger */

var AbstractGuiElement = require('./AbstractGuiElement');
var PanelControlElementType = require('./PanelControlElementType');
var Functions = require('../Functions');

var Promise = require("bluebird");

var logger = require('../logger');

function Header(params) {
  AbstractGuiElement.call(this, params);
  var self = this;

  self._createHeaderGui();
}

Header.prototype = Object.create(AbstractGuiElement.prototype);
Header.prototype.constructor = Header;

Header.prototype._createHeaderGui = function() {
  var self = this;
  self.getElement().className = "minerva-header";

  var projectId = self.getProject().getProjectId();
  var projectName = self.getProject().getName();

  var loadingDiv = Functions.createElement({
    type : "div",
    style : "display:none; ",
  });
  loadingDiv.style.float = "right";

  var loadingImg = Functions.createElement({
    type : "img",
    src : 'resources/images/icons/ajax-loader.gif',
  });
  loadingImg.style.height = "35px";
  loadingDiv.appendChild(loadingImg);
  this.setControlElement(PanelControlElementType.FOOTER_LOADING_DIV, loadingDiv);

  var link = Functions.createElement({
    type : "a",
    style : "padding-right:15px; float:right",
    content : '<i class="fa fa-lock" style="font-size:17px"></i>&nbsp;',
  });
  link.href = ServerConnector.getServerBaseUrl() + "admin.xhtml?id=" + projectId;
  self.getElement().appendChild(link);

  self.getElement().appendChild(loadingDiv);

  link = Functions.createElement({
    type : "a",
    content : '<i class="fa fa-home" style="font-size:17px"></i> ' + projectName,
  });
  link.href = ServerConnector.getServerBaseUrl() + "?id=" + projectId;
  self.getElement().appendChild(link);

  
};

Header.prototype.addLoadMessage = function(message) {
  var self = this;
  self._loadMessages.push(message);
};
Header.prototype.removeLoadMessage = function(message) {
  var self = this;
  var index = self._loadMessages.indexOf(message);
  if (index > -1) {
    self._loadMessages.splice(index, 1);
  } else {
    logger.debug("Removing message that is not there: " + message);
  }
};

Header.prototype.init = function() {
  var self = this;
  return new Promise(function(resolve) {
    var div = self.getControlElement(PanelControlElementType.FOOTER_LOADING_DIV);

    self._loadMessages = [];
    self._onDataLoadStart = function(e) {
      self.addLoadMessage(e.arg);
      div.style.display = "block";
      div.title = e.arg;
    };

    self._onDataLoadStop = function(e) {
      self.removeLoadMessage(e.arg);
      if (self._loadMessages.length > 0) {
        div.title = self._loadMessages[0];
      } else {
        div.style.display = "none";
      }
    };
    ServerConnector.addListener("onDataLoadStart", self._onDataLoadStart);
    ServerConnector.addListener("onDataLoadStop", self._onDataLoadStop);
    resolve();
  });
};

Header.prototype.destroy = function() {
  var self = this;
  ServerConnector.removeListener("onDataLoadStart", self._onDataLoadStart);
  ServerConnector.removeListener("onDataLoadStop", self._onDataLoadStop);
};

module.exports = Header;
